=============
Miscellaneous
=============

This section contains a series of miscellaneous tools
that are not directly related to the main functionality of the package,
but that can be useful in some cases.